==> com.liferay.dynamic.data.mapping.form.renderer-4.0.30.jar: META-INF/resources/js/containers/Form/Form.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.30/js/containers/Form/Form.es", ['module', 'exports', 'require', '../../components/FormRenderer/FormRenderer.es', 'frontend-js-metal-web$metal-soy', '../../components/FormRenderer/FormRenderer.soy', '../../store/withStore.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _FormRenderer = _interopRequireDefault(require("../../components/FormRenderer/FormRenderer.es"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _FormRenderer2 = _interopRequireDefault(require("../../components/FormRenderer/FormRenderer.soy"));

  var _withStore = _interopRequireDefault(require("../../store/withStore.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var Form = (0, _withStore["default"])(_FormRenderer["default"]);

  _metalSoy["default"].register(Form, _FormRenderer2["default"]);

  var _default = Form;
  exports["default"] = _default;
  //# sourceMappingURL=Form.es.js.map
});
//# sourceMappingURL=Form.es.js.map

==> com.liferay.dynamic.data.mapping.form.renderer-4.0.33.jar: META-INF/resources/js/containers/Form/Form.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-renderer@4.0.33/js/containers/Form/Form.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-soy', '../../components/FormRenderer/FormRenderer.es', '../../components/FormRenderer/FormRenderer.soy', '../../store/withStore.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _FormRenderer = _interopRequireDefault(require("../../components/FormRenderer/FormRenderer.es"));

  var _FormRenderer2 = _interopRequireDefault(require("../../components/FormRenderer/FormRenderer.soy"));

  var _withStore = _interopRequireDefault(require("../../store/withStore.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var Form = (0, _withStore["default"])(_FormRenderer["default"]);

  _metalSoy["default"].register(Form, _FormRenderer2["default"]);

  var _default = Form;
  exports["default"] = _default;
  //# sourceMappingURL=Form.es.js.map
});
//# sourceMappingURL=Form.es.js.map
